=====
Usage
=====

To use LIDAR Suit in a project::

    import lidarSuit as lst



--------------------------
Generating the config file
--------------------------


After installing lidarSuit, it is recommended to generate the configuration file (config.json). The global attributes from the NetCDF files generated by lidarSuit are defined in this file. To create the config.json, the user needs to use the lst.configuration class. Below you can find an example of how this file is generated.

.. code-block:: python

    >>> config = lst.configurations(lst=lst)
    >>> config = config.loadInstitution('institution name')
    >>> config = config.loadInstrument('instrument name')
    >>> config = config.loadSite('site name')
    >>> config = config.loadContact('contact person')
    >>> config = config.loadEmail('contact email')
    >>> config = config.loadComments('additional information')
    >>> config.generateConf()

The configuration file can also be created using the default values.

.. code-block:: python

    >>> lst.configurations(lst=lst).generateConf()

Whenever the class lst.retrieveWind() is used to retrieve wind, lidarSuit will try to load the global attributes from the config.json. If this file does not exist, lidarSuit will create it using the default values and displays the following message.

.. code-block:: python

    'You do not have a config file yet'
    'a temporary config file was generated'
    'See the documentation for generating it'